@@ -2,11 +2,11 @@
 
 __revision__ = '$Id:'
 
-defined = 1
+DEFINED = 1
 
-if defined != 1:
-    if defined in (unknown, defined):
-        defined += 1
+if DEFINED != 1:
+    if DEFINED in (unknown, DEFINED):
+        DEFINED += 1
 
 
 def in_method(var):
@@ -14,10 +14,10 @@ def in_method(var):
     var = nomoreknown
     assert var
 
-defined = {defined:__revision__}
-defined[__revision__] = other = 'move this is astng test'
+DEFINED = {DEFINED:__revision__}
+DEFINED[__revision__] = OTHER = 'move this is astng test'
 
-other += '$'
+OTHER += '$'
 
 def bad_default(var, default=unknown2):
     """function with defaut arg's value set to an unexistant name"""
